@@ -144,14 +144,33 @@ tar_callr_inner_try <- function(
   }
   old_envir <- targets::tar_option_get("envir")
   targets::tar_option_set(envir = envir)
-  targets::tar_runtime_object()$set_script(script)
-  targets::tar_runtime_object()$set_store(store)
-  targets::tar_runtime_object()$set_fun(fun)
+  tar_runtime <- targets::tar_runtime_object()
+  tar_runtime$script <- script
+  tar_runtime$store <- store
+  tar_runtime$working_directory <- getwd()
+  tar_runtime$fun <- fun
+  objects <- list.files(
+    path = targets::tar_path_objects_dir(store),
+    all.files = TRUE,
+    full.names = TRUE,
+    no.. = TRUE
+  )
+  tar_runtime$file_exist <- targets::tar_counter(names = objects)
+  tar_runtime$file_info_exist <- targets::tar_counter(names = objects)
+  file_info <- as.list(file_info(objects)[, c("size", "mtime_numeric")])
+  names(file_info$size) <- objects
+  names(file_info$mtime_numeric) <- objects
+  tar_runtime$file_info <- file_info
   on.exit(targets::tar_option_set(envir = old_envir))
-  on.exit(targets::tar_runtime_object()$unset_script(), add = TRUE)
-  on.exit(targets::tar_runtime_object()$unset_store(), add = TRUE)
-  on.exit(targets::tar_runtime_object()$unset_fun(), add = TRUE)
-  withr::local_options(options)
+  on.exit(tar_runtime$script <- NULL, add = TRUE)
+  on.exit(tar_runtime$store <- NULL, add = TRUE)
+  on.exit(tar_runtime$working_directory <- NULL, add = TRUE)
+  on.exit(tar_runtime$fun <- NULL, add = TRUE)
+  on.exit(tar_runtime$file_exist <- NULL, add = TRUE)
+  on.exit(tar_runtime$file_info <- NULL, add = TRUE)
+  on.exit(tar_runtime$file_info_exist <- NULL, add = TRUE)
+  old <- options(options)
+  on.exit(options(old), add = TRUE)
   targets <- eval(parse(text = readLines(script, warn = FALSE)), envir = envir)
   targets_arguments$pipeline <- targets::tar_as_pipeline(targets)
   targets::tar_pipeline_validate_lite(targets_arguments$pipeline)
