@@ -18,8 +18,8 @@ tar_test("tar_path() with a name arg", {
 tar_test("tar_path() inside a pipeline", {
   skip_cran()
   x <- target_init("x", quote(suppressWarnings(targets::tar_path())))
-  tar_runtime$set_store(path_store_default())
-  on.exit(tar_runtime$unset_store())
+  tar_runtime$store <- path_store_default()
+  on.exit(tar_runtime$store <- NULL)
   pipeline <- pipeline_init(list(x))
   local_init(pipeline)$run()
   path <- file.path("_targets", "objects", "x")
@@ -63,11 +63,11 @@ tar_test("tar_path() returns non-cloud path for non-cloud storage formats", {
   skip_cran()
   x <- tar_target(x, 1, format = "parquet")
   on.exit({
-    tar_runtime$unset_store()
-    tar_runtime$unset_target()
+    tar_runtime$store <- NULL
+    tar_runtime$target <- NULL
   })
-  tar_runtime$set_store(path_store_default())
-  tar_runtime$set_target(x)
+  tar_runtime$store <- path_store_default()
+  tar_runtime$target <- x
   out <- suppressWarnings(tar_path(create_dir = FALSE))
   expect_false(file.exists(dirname(out)))
   out <- suppressWarnings(tar_path(create_dir = TRUE))
@@ -81,9 +81,9 @@ tar_test("tar_path() returns stage for cloud formats", {
   store_update_stage_early(x$store, x$settings$name, path_store_default())
   dir <- dirname(x$store$file$stage)
   unlink(dir, recursive = TRUE)
-  on.exit(tar_runtime$unset_target())
+  on.exit(tar_runtime$target <- NULL)
   on.exit(unlink(dir, recursive = TRUE), add = TRUE)
-  tar_runtime$set_target(x)
+  tar_runtime$target <- x
   out <- suppressWarnings(tar_path(create_dir = FALSE))
   expect_false(file.exists(dirname(out)))
   out <- suppressWarnings(tar_path(create_dir = TRUE))
